@@ -6,7 +6,7 @@ pub use self::model::*;
 pub(crate) mod activity_matcher;
 
 mod geo_serializer;
-pub use self::geo_serializer::serialize_solution_as_geojson;
+pub use self::geo_serializer::*;
 
 mod initial_reader;
 pub use self::initial_reader::read_init_solution;
@@ -40,6 +40,7 @@ fn map_code_reason(code: i32) -> (&'static str, &'static str) {
             ("TOUR_SIZE_CONSTRAINT", "cannot be assigned due to tour size constraint of vehicle")
         }
         TOUR_ORDER_CONSTRAINT_CODE => ("TOUR_ORDER_CONSTRAINT_CODE", "cannot be assigned due to tour order constraint"),
+        GROUP_CONSTRAINT_CODE => ("GROUP_CONSTRAINT_CODE", "cannot be assigned due to group constraint"),
         _ => ("NO_REASON_FOUND", "unknown"),
     }
 }
@@ -59,6 +60,7 @@ fn map_reason_code(reason: &str) -> i32 {
         "DISPATCH_CONSTRAINT" => DISPATCH_CONSTRAINT_CODE,
         "TOUR_SIZE_CONSTRAINT" => TOUR_SIZE_CONSTRAINT_CODE,
         "TOUR_ORDER_CONSTRAINT_CODE" => TOUR_ORDER_CONSTRAINT_CODE,
+        "GROUP_CONSTRAINT_CODE" => GROUP_CONSTRAINT_CODE,
         _ => -1,
     }
 }
